aWherePy: A Python Package for the aWhere API
=============================================

`aWherePy` is a Python package that provides functionality to call, extract, and format data from the `aWhere API <https://www.awhere.com/developer/>`_. aWherePy allows for the creation of reproducible science workflows with Python scripts and/or Jupyter Notebooks and creates the vehicle to integrate aWhere data with other geospatial and remote sensing data within these platforms.

Contributions to `aWherePy` are welcome.

aWherePy User Guide
===================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   get-started
   Examples Gallery <gallery_vignettes/index>
   api
   contributing
   contributors
   change-log
   code-of-conduct

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
